#

##

##

    	grove

    	description

    		This is a list of the ingredients in a "land"

    	structure

    		[
    			{
    				"info": {
    					"includes": [],
    					"names": [
    						"protein"
    					],
    					"region": 1
    				},
    				"measures": {
    					"mass + mass equivalents": {
    						"per recipe": {
    							"grams": {
    								"fraction string": "163994710149766829/3518437208883200",
    								"scinote string": "4.6610e+1"
    							}
    						},
    						"portion of grove": {
    							"fraction string": "2317946433212252000/3447786989728825129",
    							"scinote percentage string": "6.7230e+1"
    						}
    					}
    				},
    				"natures": [
    					{
    						"amount": "1",
    						"source": {
    							"name": "PLANT-BASED CHOPPED CHICK'N",
    							"FDC ID": "2510083",
    							"UPC": "850002856132",
    							"DSLD ID": ""
    						},
    						"ingredient": {
    							"name": "Protein"
    						},
    						"measures": {
    							"mass + mass equivalents": {
    								"per package": {
    									"listed": [
    										"46.610",
    										"g"
    									],
    									"grams": {
    										"scinote string": "4.6610e+1",
    										"decimal string": "46.610",
    										"fraction string": "163994710149766829/3518437208883200"
    									}
    								}
    							}
    						}
    					}
    				],
    				"unites": [],
    				"goals": {
    					"days of ingredient": {
    						"mass + mass equivalents": {
    							"per recipe": {
    								"fraction string": "163994710149766829/175921860444160000",
    								"decimal string": "0.932"
    							}
    						}
    					}
    				}
    			}
    		]